==> pyside-setup-opensource-src-6.0.4.zip: pyside-setup-opensource-src-6.0.4/sources/pyside6/tests/QtCore/qregularexpression_test.py <==
#!/usr/bin/python

#############################################################################
##
## Copyright (C) 2017 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''Unit tests for QRegularExpression'''

import os
import sys
import unittest

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from init_paths import init_test_paths
init_test_paths(False)

from PySide6.QtCore import QRegularExpression, QRegularExpressionMatch, QRegularExpressionMatchIterator

class QRegularExpressionTest(unittest.TestCase):

    def testMatch(self):
        re = QRegularExpression('^.*(word2).*$')
        self.assertTrue(re.isValid())
        match = re.match('word1 word2  word3')
        self.assertTrue(match.isValid())
        self.assertEqual(match.captured(1), 'word2')
        self.assertEqual(match.capturedView(1), 'word2')

    def testMatchIterator(self):
        re = QRegularExpression('(\w+)')
        self.assertTrue(re.isValid())
        count = 0
        it = re.globalMatch('word1 word2 word3');
        while it.hasNext():
            it.next()
            count = count  + 1
        self.assertEqual(count, 3)

if __name__ == '__main__':
    unittest.main()

==> pyside-setup-opensource-src-6.2.3.zip: pyside-setup-opensource-src-6.2.3/sources/pyside6/tests/QtCore/qregularexpression_test.py <==
#!/usr/bin/python

#############################################################################
##
## Copyright (C) 2017 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''Unit tests for QRegularExpression'''

import os
import sys
import unittest

from pathlib import Path
sys.path.append(os.fspath(Path(__file__).resolve().parents[1]))
from init_paths import init_test_paths
init_test_paths(False)

from PySide6.QtCore import QRegularExpression, QRegularExpressionMatch, QRegularExpressionMatchIterator


class QRegularExpressionTest(unittest.TestCase):

    def testMatch(self):
        re = QRegularExpression('^.*(word2).*$')
        self.assertTrue(re.isValid())
        match = re.match('word1 word2  word3')
        self.assertTrue(match.isValid())
        self.assertEqual(match.captured(1), 'word2')
        self.assertEqual(match.capturedView(1), 'word2')

    def testMatchIterator(self):
        re = QRegularExpression('(\w+)')
        self.assertTrue(re.isValid())
        count = 0
        it = re.globalMatch('word1 word2 word3')
        while it.hasNext():
            it.next()
            count = count + 1
        self.assertEqual(count, 3)


if __name__ == '__main__':
    unittest.main()
